/**
 * @file          /ks-license/include/license_i.h
 * @brief
 * @author        tangjie02 <tangjie02@kylinos.com.cn>
 * @copyright (c) 2020 KylinSec. All rights reserved.
 */

#pragma once

#ifndef LICENSE_NEW_INTERFACE
#warning This file will be deprecated. please use license-i.h file
#endif

enum LicenseActivationStatus
{
    // 未激活
    LAS_UNACTIVATED = 0,
    // 已激活
    LAS_ACTIVATED,
    LAS_LAST,
};

enum LicenseServiceStatus
{
    /* 非法，如果当前时间比安装时间小很多说明用户手动修改了时间，可以当作已过期处理，如果条件允许，需要向用户报告该错误
       该枚举标识符已弃用请使用：LicenseExceptionStatus::LICENSE_EXCEPTION_STATUS_INVALID*/
    LICENSE_SERVICE_STATUS_INVALID = 0,
    // 已过质保期，当前时间大于过期时间
    LICENSE_SERVICE_STATUS_EXPIRED,
    // 未过质保期，可正常提供人工服务
    LICENSE_SERVICE_STATUS_UNEXPIRED,
    LICENSE_SERVICE_STATUS_LAST,
};

enum LicenseExceptionStatus
{
    LICENSE_EXCEPTION_STATUS_NONE = 0,
    // 非法，如果当前时间比安装时间小很多说明用户手动修改了时间，可以当作已过期处理，如果条件允许，需要向用户报告该错误
    LICENSE_EXCEPTION_STATUS_INVALID,
    // 未过质保期，但激活码异常，需要跟激活服务器保持连接
    LICENSE_EXCEPTION_STATUS_SERVER_NOT_CONNECTED,
    // 未过质保期，服务器和客户端时差过大
    LICENSE_EXCEPTION_STATUS_CS_TIME_DIFF_TOO_MUCH,
    LICENSE_EXCEPTION_STATUS_LAST,
};

enum LicenseInstallType
{
    // 下面是老的安装形态类型，以后生成的授权码不再使用
    // 桌面应用终端
    LICENSE_INSTALL_TYPE_OLD_DESKTOP = 1,
    // 服务器运行版本
    LICENSE_INSTALL_TYPE_OLD_SERVER,
    // 工作站运行版本
    LICENSE_INSTALL_TYPE_OLD_WORKSTATION,
    // 工控版本
    LICENSE_INSTALL_TYPE_OLD_INDUSTRIAL,
    LICENSE_INSTALL_TYPE_OLD_LAST,

    // 桌面虚拟机版本
    LICENSE_INSTALL_TYPE_VIRTUAL_DESKTOP = 6,
    // 服务器虚拟机版
    LICENSE_INSTALL_TYPE_VIRTUAL_SERVER,
    // 工控虚拟机版
    LICENSE_INSTALL_TYPE_VIRTUAL_INDUSTRIAL,
    LICENSE_INSTALL_TYPE_VIRTUAL_LAST,

    // 下面是新的安装形态类型
    // 不限定，为了兼容没有/etc/.installclass文件或者其他情况
    LICENSE_INSTALL_TYPE_UNLIMIT = 11,
    LICENSE_INSTALL_TYPE_UNKNOWN = 11,
    // 桌面版
    LICENSE_INSTALL_TYPE_DESKTOP,
    // 服务器版
    LICENSE_INSTALL_TYPE_SERVER,
    // 工控版
    LICENSE_INSTALL_TYPE_INDUSTRIAL,
    // 开发版
    LICENSE_INSTALL_TYPE_DEVELOPMENT,
    LICENSE_INSTALL_TYPE_LAST,
};

// 更新模式在字节中的起始位置
#define LICENSE_UPDATE_MODE_BIT_POS 0
// 更新服务
enum LicenseUpdateMode
{
    // 无
    LICENSE_UPDATE_MODE_NONE,
    // 永久模式
    LICENSE_UPDATE_MODE_PERMANENT,
    // 订阅模式
    LICENSE_UPDATE_MODE_SUBSCRIBE,
};

// 人工服务模式在字节中的起始位置
#define LICENSE_SERVICE_MODE_BIT_POS 2
// 人工服务模式
enum LicenseServiceMode
{
    // 无
    LICENSE_SERVICE_MODE_NONE,
    // 7X24小时
    LICENSE_SERVICE_MODE_7X24,
    // 5X8小时
    LICENSE_SERVICE_MODE_5X8,
};

// 激活类型在字节中的起始位置
#define LICENSE_ACTIVATION_TYPE_BIT_POS 4
enum LicenseActivationType
{
    // 未知
    LICENSE_ACTIVATION_TYPE_UNKNOWN = 0,
    // 手动激活
    LICENSE_ACTIVATION_TYPE_MANNUAL,
    // 离线批量激活
    LICENSE_ACTIVATION_TYPE_OFFLINE,
    // 在线激活
    LICENSE_ACTIVATION_TYPE_ONLINE,
    // 文件导入激活
    LICENSE_ACTIVATION_TYPE_FILE,
};

// 机器类型在字节中的起始位置
#define LICENSE_MACHINE_TYPE_BIT_POS 7
enum LicenseMachineType
{
    // 物理机
    LICENSE_MACHINE_TYPE_PHYSICAL,
    // 虚拟机
    LICENSE_MACHINE_TYPE_VIRTUAL,
};

// 客户端连接状态
enum ClientConnectionStatus
{
    // 在线
    CLIENT_CONNECTION_STATUS_ONLINE,
    // 离线
    CLIENT_CONNECTION_STATUS_OFFLINE,
};

// 计算质保期模式
enum ComputeExpiryDayMode
{
    COMPUTE_EXPIRY_NONE,
    // 固定质保期
    COMPUTE_EXPIRY_DAY_FIXED,
    // 质保期按照激活时间计算
    COMPUTE_EXPIRY_DAY_BY_ACTIVATE,
};

// 质保周期类型
enum LicensePeriodType
{
    LICENSE_PERIOD_TYPE_NONE,
    // 固定质保期
    LICENSE_PERIOD_TYPE_TIMES,
    // 按天计算
    LICENSE_PERIOD_TYPE_DAYS,
    // 按月计算
    LICENSE_PERIOD_TYPE_MONTHS,
    // 按年计算
    LICENSE_PERIOD_TYPE_YEARS,
};

enum LicenseDatabaseAction
{
    IMPORT_DB_OPRATION_NONE,
    // 插入新的激活服务号
    IMPORT_DB_OPRATION_INSERT,
    // 重新写入激活服务号
    IMPORT_DB_OPRATION_REWRITE,
    // 重置激活服务点数
    IMPORT_DB_OPRATION_RESETPOINTS,
};

enum PUKeyAddrOffset
{
    // 机器码存储区
    PUKEY_ADDR_OFFSET_MACHINE_CODE = 0,
    // 到期时间存储区
    PUKEY_ADDR_OFFSET_MACHINE_EXPIRY_DATE = 3855,
    // 私钥存储区域
    PUKEY_ADDR_OFFSET_PRIVATE_KEY = 6168,
    // 服务号
    PUKEY_ADDR_OFFSET_UID = 7168,
    // 硬件序列号
    PUKEY_ADDR_OFFSET_HARD_ID = 7200,
    // 客户信息
    PUKEY_ADDR_OFFSET_CUSTOMER_INFO = 7216,
    // 激活对象
    PUKEY_ADDR_OFFSET_OBJECT_NAME = 7240,
    // 质保期
    PUKEY_ADDR_OFFSET_EXPIRY_DATE = 7256,
    // 安装类型
    PUKEY_ADDR_OFFSET_INSTALL_TYPE = 7264,
    // 更新模式
    PUKEY_ADDR_OFFSET_UPDATE_MODE = 7265,
    // 人工服务模式
    PUKEY_ADDR_OFFSET_ARTIFICIAL_SERVICE_MODE = 7266,
    // 总激活点数
    PUKEY_ADDR_OFFSET_SUM_POINTS = 7267,
    // 剩余激活点数
    PUKEY_ADDR_OFFSET_REMAINING_POINTS = 7271,
    // 合同号
    PUKEY_ADDR_OFFSET_CONTRACT_NUM = 7275,
    // 项目名称
    PUKEY_ADDR_OFFSET_SUBJECT_NAME = 7323,
    // 计算过期时间方式
    PUKEY_ADDR_OFFSET_COMPUTE_EXPIRY_DAY_MODE = 7387,
    // 质保年数
    PUKEY_ADDR_OFFSET_WARRANTY_YEARS = 7388,
    // 质保月数
    PUKEY_ADDR_OFFSET_WARRANTY_MONTHS = 7390,
    // 质保天数
    PUKEY_ADDR_OFFSET_WARRANTY_DAYS = 7392,
    // 定制客户
    PUKEY_ADDR_OFFSET_CUSTOMIZATION_CUSTOMER = 7394,
    // 客户公司名称
    PUKEY_ADDR_OFFSET_CUSTOMER_COMPANY_NAME = 7426,
    PUKEY_ADDR_OFFSET_CUR_LAST = 7480,
    PUKEY_ADDR_OFFSET_LAST = 8192,
};

enum LicenseCryptoType
{
    LICENSE_CRYPTO_TYPE_NONE,
    LICENSE_CRYPTO_TYPE_DES,
    LICENSE_CRYPTO_TYPE_AES,
    LICENSE_CRYPTO_TYPE_RSA,
};

enum LicenseErrorCode
{
    LEC_SUCCESS = 0,

    /* ------------ common ------------- */
    LEC_COMMON_NULL_POINTER,
    LEC_COMMON_UNSUPPORTED_OPERATION,
    LEC_COMMON_IO_ERROR,

    /* ------------ license ------------- */
    // 授权码长度错误
    LEC_LICENSE_LENGTH_INVALID = 1000,
    // 字符串形式的授权码无法转换为2进制表示的授权码
    LEC_LICENSE_TRANS_FAILED,
    // 无法解密16字节的授权码
    LEC_LICENSE_DECODE_FAILED,
    // 解密成功，但是解密后的日期部分不是一个合法的日期格式
    LEC_LICENSE_DATE_INVALID,
    // 机器码和授权码不匹配
    LEC_UNMATCH_MACHINE_CODE,
    // 机器码匹配，但是机器码中的安装形态是桌面版的，而当前机器是服务器
    LEC_INSTALL_TYPE_UNMATCH_MACHINE,
    // 授权码已过期
    LEC_LICENSE_EXPIRED,
    // 字符串形式的机器码无法转换为2进制表示的机器码
    LEC_MACHINE_CODE_TRANS_FAILED,
    // 授权码同步到文件(/etc/.license)失败
    LEC_SYNC_TO_FILE_FAILED,
    // 过期时间超过2100年
    LEC_EXPIRED_DATE_LARGE,
    // 机器码与安装形态不匹配
    MACHINE_CODE_UNMATCH_INSTALL_TYPE,
    // 激活码类型错误
    LEC_LICENSE_ACTIVATION_CODE_TYPE_ERROR,
    // 不支持在线激活
    LEC_LICENSE_NOT_SUPPORT_ONLINE_ACTIVATION,
    // 未激活操作系统激活增值业务
    LEC_UNACTIVE_OS_FORBID_ACTIVE_VA,
    // 操作系统激活过期禁止增值业务
    LEC_OS_LICENSE_EXPIRY_FORBID_ACTIVE_VA,
    // 激活码使用过一次
    LEC_LICENSE_USED_ONES,
    // 安装时间非法：安装时间大于当前时间
    LEC_LICENSE_INSTALL_TIME_INVALID,
    // 授权码不可用
    LEC_LICENSE_NOT_AVAILABLE,
    // 加密方式不正确
    LEC_CRYPTO_TYPE_ERROR,
    // 解析JSON字符串失败
    LEC_PRASE_JSON_ERROR,
    // 激活类型不匹配
    LEC_ACTIVATION_TYPE_MISMACHED,
    // 无法找到公钥
    LEC_NOT_FOUND_PUBLIC_KEY,
    // 无法找到私钥
    LEC_NOT_FOUND_PRIVATE_KEY,
    // 激活文件格式错误
    LEC_ACTIVATION_FILE_FORMAT_ERROR,
    // 激活码字符串错误，字符串出现了'A~Z'和'0~9'之外的字符
    LEC_ACTIVATION_CODE_STR_ERROR,

    /* ------------ ukey ------------- */
    // UkeyGroup未初始化
    LEC_UKEY_GROUP_UNINIT = 2000,
    // 没有找到UKey设备
    LEC_UKEY_NOT_FOUND,
    // 存在UKey设备但已经没有点数或者已经过期
    LEC_UKEY_NOT_USABLE_UKEY_DEVICE,
    // UKey设备记录的过期时间不是合法格式
    LEC_UKEY_EXPIRED_DATE_INVALIDE,
    // 根据机器码、过期时间、客户信息加密未授权码失败
    LEC_ENCODE_GENERATE_LICENSE_FAILED,
    // 生成的授权码二进制长度错误
    LEC_GENERATE_LICENSE_LENGTH_INALID,
    // 同步已激活信息到数据库失败
    LEC_SYNC_ACTIVATION_TO_DB_FAILED,
    // 同步点数信息到数据库失败
    LEC_SYNC_POINTS_TO_DB_FAILED,
    // 非x86机器使用物理ukey设备
    LEC_UKEY_UNSUPPORTED_ARCH,
    // 调用c51程序生成授权码失败
    LEC_C51_GENERATE_LICENSE_FAILED,
    // 已授权机器超过最大内存
    LEC_UKEY_ITEM_EXCEED_LIMIT,
    // USBKey设备PIN验证失败
    LEC_UKEY_PIN_FAILED,
    // 写入机器码到USBKey设备失败
    LEC_UKEY_WRITE_MACHINE_CODE_FAILED,
    // 更新USBKey设备剩余点数
    LEC_UKEY_WRITE_REMAINING_POINTS_FAILED,
    // 机器码已经存在UKey中
    LEC_UKEY_ALREADY_EXIST_MACHINE_CODE,
    // 存在UKey设备但已经没有点数
    LEC_UKEY_NO_REMAINING_POINTS,
    // 机器码不存在UKey中
    LEC_UKEY_NOT_EXIST_MACHINE_CODE,
    // 不存在已使用点数
    LEC_UKEY_NO_USED_POINTS,
    // 不支持UKey激活
    LEC_LICENSE_NOT_SUPPORT_UKEY_ACTIVATION,

    /* ------------ online ------------- */
    // 连接服务器失败
    LEC_CONNECT_SERVER_FAILED = 3000,
    // 发送激活请求失败
    LEC_SEND_ACTIVATION_REQUEST_FAILED,
    // 等待服务器的响应数据超时
    LEC_SERVER_RESPONSE_TIMEOUT,
    // 服务器响应数据错误
    LEC_SERVER_RESPONSE_ERROR,
    // 没有找到服务号
    LEC_SERVER_SERVICE_UID_NOT_FOUND,
    // 没有找到激活记录
    LEC_SERVER_ACTIVATION_RECORD_NOT_FOUND,
    // 服务器和客户端时差过大
    LEC_SERVER_CS_TIME_DIFF_TOO_MUCH,
    // 机器类型不匹配
    LEC_SERVER_MACHINE_TYPE_DISMATCH,
    // 导入点数记录状态过期
    LEC_SERVER_IMPORT_POINTS_STATUS_EXPIRED,
    // 导入点数记录已存在
    LEC_SERVER_IMPORT_POINTS_ALREADY_EXISTS,
    // 无剩余点数
    LEC_SERVER_NO_REMAINING_POINTS,
    // 请求页码错误
    LEC_SERVER_REQUEST_PAGE_NO_ERROR,
    // 激活对象的的名称错误
    LEC_SERVER_ACTIVATION_OBJECT_MISMATCH,
    // 初始化服务号失败
    LEC_SERVER_INIT_POINTS_FAILED,
    // 生成过期时间失败
    LEC_SERVER_GENERATE_EXPIRY_TIME_FAILED,
    // 周期类型非法
    LEC_SERVER_PERIOD_TYPE_INVALID,
    // 机器码已经存在服务中
    LEC_SERVER_ALREADY_EXIST_MACHINE_CODE,
    // 机器码不存在服务中
    LEC_SERVER_NOT_EXIST_MACHINE_CODE,
    // 激活记录更新失败
    LEC_SERVER_ACTIVATION_RECORD_UPDATE_FAILED,
    // 定制客户名称不匹配
    LEC_CUSTOMIZATION_CUSTOMER_NAME_MISMATCH,
    // 生成序列号失败
    LEC_GENERATE_SERIAL_NMU_FAILED,
    // 生成激活密钥失败
    LEC_GENERATE_ACTIVATION_BLOB_FAILED,
    // 服务端客户端过期时间不一致
    LEC_SERVER_EXPIRY_TIME_DIFF_WITH_CLIENT,
    // 读取服务号数据失败
    LEC_READ_LICENSE_POINTS_RECORD_FAILED,
    // 服务号不支持回收操作
    LEC_SERVER_SERVICE_NOT_SUPPORT_RECYCLE,
    // 不能回收在线的机器
    LEC_UNABLE_RECYCLE_ONLINE_MACHINE,
    // 未回收的机器无法删除
    LEC_UNABLE_DELETE_UNRECYCLED_MACHINE,
    // 支持回收的服务号无法初始化UKEY
    LEC_SUPPORT_RECYCLE_SERVICE_CANNOT_INIT_UKEY,
    // 绑定的服务器地址和输入的服务器地址不一致
    LEC_BINDING_SERVER_ADDR_DIFF_WITH_INPUT,
    // 机器已被自动回收
    LEC_MACHINE_HAS_BEEN_RECYCLING_AUTOMATIC,

    /* ------------ generator ------------- */
    // 输入的日期不合法
    LEC_INPUT_DATE_INVALID = 4000,
    // 客户代码长度错误
    LEC_INPUT_CUSTOMER_LENGTH_INVALID,
    // 客户代码非法
    LEC_CUSTOMER_INFO_INVALID,
    // 只允许重置一次安装时间
    LEC_ONLY_ALLOW_RESET_BOOT_TIME_ONCE,

    /*--------------activation file----------------*/
    // 不存在激活文件
    LEC_FILE_ABSENT = 5000,

    LEC_UNKNOWN = 10000,

};

/* ---------------------- DBUS -------------------- */
// deprecated macro definition
#define LICENSE_DBUS_NAME "com.kylinsec.Kiran.LicenseHelper"
#define LICENSE_DBUS_OBJECT_PATH "/com/kylinsec/Kiran/LicenseHelper"

#define LICENSE_HELPER_DBUS_NAME "com.kylinsec.Kiran.LicenseHelper"
#define LICENSE_HELPER_OBJECT_PATH "/com/kylinsec/Kiran/LicenseHelper"
#define LICENSE_MANAGER_DBUS_NAME "com.kylinsec.Kiran.LicenseManager"
#define LICENSE_MANAGER_OBJECT_PATH "/com/kylinsec/Kiran/LicenseManager"
#define LICENSE_OBJECT_DBUS_NAME "com.kylinsec.Kiran.LicenseObject"
#define LICENSE_OBJECT_OBJECT_PATH "/com/kylinsec/Kiran/LicenseObject"

#define LICENSE_DBUS_TIMEOUT_MSEC 3000
#define LICENSE_CLIENT_TIMEOUT_SEC 2

// 操作系统授权名称
#define LICENSE_OBJECT_OS_NAME "KylinSecOS"

//
#define LICENSE_JK_ACTIVATION_STATUS "activation_status"
#define LICENSE_JK_SERVICE_STATUS "service_status"
#define LICENSE_JK_MACHINE_CODE "machine_code"
#define LICENSE_JK_EXPIRED_TIME "expired_time"
#define LICENSE_JK_FIRST_BOOT_TIME "first_boot_time"
#define LICENSE_JK_INSTALL_TYPE "install_type"
#define LICENSE_JK_IS_PG "is_pg"
#define LICENSE_JK_ACTIVATION_CODE "activation_code"
#define LICENSE_JK_ACTIVATION_TYPE "activation_type"
#define LICENSE_JK_ACTIVATION_TIME "activation_time"
#define LICENSE_JK_CUSTOMER_INFO "customer_info"
#define LICENSE_JK_UPDATE_MODE "update_mode"
#define LICENSE_JK_SERVICE_MODE "service_mode"
#define LICENSE_JK_EXCEPTION_STATUS "exception_status"
#define LICENSE_JK_SERVICE_UID "service_uid"
#define LICENSE_JK_SERIAL_NUM "serial_number"
#define LICENSE_JK_CUSTOMER_COMPANY_NAME "customer_company_name"
#define LICENSE_JK_SUBJECT_NAME "subject_name"
#define LICENSE_JK_TELEPHONE "telephone"
#define LICENSE_JK_RESTRICTION_POLICY "restriction_policy"

#define LICENSE_JK_SUM_POINTS "sum_points"
#define LICENSE_JK_REMAINING_POINTS "remaining_points"

// 文件导入激活
#define LICENSE_FILE_OBJECT "Activation File"
#define LICENSE_FILE_PRIVATE_KEY "RSAPrivateKey"
#define LICENSE_FILE_ACTIVATION_BLOB "ActivationBlob"

// 已激活机器码
#define RY3_ACTIVATED_MACHIEN_CODE (PUKeyAddrOffset::PUKEY_ADDR_OFFSET_MACHINE_EXPIRY_DATE - PUKeyAddrOffset::PUKEY_ADDR_OFFSET_MACHINE_CODE)
// 已激活机器到期时间
#define RY3_MACHINE_EXPIRY_DATE (PUKeyAddrOffset::PUKEY_ADDR_OFFSET_PRIVATE_KEY - PUKeyAddrOffset::PUKEY_ADDR_OFFSET_MACHINE_EXPIRY_DATE)
// RSA私钥
#define RY3_RSA_PRIVATE_KEY (PUKeyAddrOffset::PUKEY_ADDR_OFFSET_UID - PUKeyAddrOffset::PUKEY_ADDR_OFFSET_PRIVATE_KEY)
// 服务号
#define RY3_UID_BYTES (PUKeyAddrOffset::PUKEY_ADDR_OFFSET_HARD_ID - PUKeyAddrOffset::PUKEY_ADDR_OFFSET_UID)
// 硬件序列号偏移(16字节)
#define RY3_HARDINFO_BYTES (PUKeyAddrOffset::PUKEY_ADDR_OFFSET_CUSTOMER_INFO - PUKeyAddrOffset::PUKEY_ADDR_OFFSET_HARD_ID)
// 客户信息
#define RY3_CUSTOMER_INFO_BYTES (PUKeyAddrOffset::PUKEY_ADDR_OFFSET_OBJECT_NAME - PUKeyAddrOffset::PUKEY_ADDR_OFFSET_CUSTOMER_INFO)
// 激活对象
#define RY3_OBJECT_NAME_BYTES (PUKeyAddrOffset::PUKEY_ADDR_OFFSET_EXPIRY_DATE - PUKeyAddrOffset::PUKEY_ADDR_OFFSET_OBJECT_NAME)
// 质保期
#define RY3_EXPIRY_DATE_BYTES (PUKeyAddrOffset::PUKEY_ADDR_OFFSET_INSTALL_TYPE - PUKeyAddrOffset::PUKEY_ADDR_OFFSET_EXPIRY_DATE)
// 安装类型
#define RY3_INSTALL_TYPE_BYTES (PUKeyAddrOffset::PUKEY_ADDR_OFFSET_UPDATE_MODE - PUKeyAddrOffset::PUKEY_ADDR_OFFSET_INSTALL_TYPE)
// 更新模式
#define RY3_UDPATE_MODE_BYTES (PUKeyAddrOffset::PUKEY_ADDR_OFFSET_ARTIFICIAL_SERVICE_MODE - PUKeyAddrOffset::PUKEY_ADDR_OFFSET_UPDATE_MODE)
// 人工服务模式
#define RY3_ARTIFICIAL_SERVICE_MODE_BYTES (PUKeyAddrOffset::PUKEY_ADDR_OFFSET_SUM_POINTS - PUKeyAddrOffset::PUKEY_ADDR_OFFSET_ARTIFICIAL_SERVICE_MODE)
// 总激活点数
#define RY3_SUM_POINTS_BYTES (PUKeyAddrOffset::PUKEY_ADDR_OFFSET_REMAINING_POINTS - PUKeyAddrOffset::PUKEY_ADDR_OFFSET_SUM_POINTS)
// 剩余激活点数
#define RY3_REMAINING_POINTS_BYTES (PUKeyAddrOffset::PUKEY_ADDR_OFFSET_CONTRACT_NUM - PUKeyAddrOffset::PUKEY_ADDR_OFFSET_REMAINING_POINTS)
// 合同号
#define RY3_CONTRACT_NO_BYTES (PUKeyAddrOffset::PUKEY_ADDR_OFFSET_SUBJECT_NAME - PUKeyAddrOffset::PUKEY_ADDR_OFFSET_CONTRACT_NUM)
// 项目名称
#define RY3_SUBJECT_NAME_BYTES (PUKeyAddrOffset::PUKEY_ADDR_OFFSET_COMPUTE_EXPIRY_DAY_MODE - PUKeyAddrOffset::PUKEY_ADDR_OFFSET_SUBJECT_NAME)
// 计算过期时间方式
#define RY3_COMPUTE_EXPIRY_DAY_MODE_BYTES (PUKeyAddrOffset::PUKEY_ADDR_OFFSET_WARRANTY_YEARS - PUKeyAddrOffset::PUKEY_ADDR_OFFSET_COMPUTE_EXPIRY_DAY_MODE)
// 质保年数
#define RY3_WARRANTY_YEARS_BYTES (PUKeyAddrOffset::PUKEY_ADDR_OFFSET_WARRANTY_MONTHS - PUKeyAddrOffset::PUKEY_ADDR_OFFSET_WARRANTY_YEARS)
// 质保月数
#define RY3_WARRANTY_MONTHS_BYTES (PUKeyAddrOffset::PUKEY_ADDR_OFFSET_WARRANTY_DAYS - PUKeyAddrOffset::PUKEY_ADDR_OFFSET_WARRANTY_MONTHS)
// 质保天数
#define RY3_WARRANTY_DAYS_BYTES (PUKeyAddrOffset::PUKEY_ADDR_OFFSET_CUSTOMIZATION_CUSTOMER - PUKeyAddrOffset::PUKEY_ADDR_OFFSET_WARRANTY_DAYS)
// 定制客户
#define RY3_CUSTOMIZATION_CUSTOMER_BYTES (PUKeyAddrOffset::PUKEY_ADDR_OFFSET_CUSTOMER_COMPANY_NAME - PUKeyAddrOffset::PUKEY_ADDR_OFFSET_CUSTOMIZATION_CUSTOMER)
// 客户公司名称
#define RY3_CUSTOMER_COMPANY_NAME (PUKeyAddrOffset::PUKEY_ADDR_OFFSET_CUR_LAST - PUKeyAddrOffset::PUKEY_ADDR_OFFSET_CUSTOMER_COMPANY_NAME)

// 废弃，请使用LicenseActivationStatus
enum LicenseStatus
{
    // 未注册
    LICENSE_STATUS_UNREGISTERD = 0,
    // 已注册
    LICENSE_STATUS_REGISTERD,
    LICENSE_STATUS_LAST,
};

// 废弃，请使用LicenseActivationType
enum LicenseRegisterType
{
    // 未知
    LICENSE_REGISTER_TYPE_UNKNOWN = 0,
    // 手动注册
    LICENSE_REGISTER_TYPE_MANNUAL,
    // 离线批量注册
    LICENSE_REGISTER_TYPE_OFFLINE,
    // 在线注册
    LICENSE_REGISTER_TYPE_ONLINE,
};